macro_rules! assert_size {
($ty:ty, $expected:expr $(,)?) => { ... };
}Expand description
Asserts that the size of a type is equal to size.
macro_rules! assert_size {
($ty:ty, $expected:expr $(,)?) => { ... };
}Asserts that the size of a type is equal to size.