Module client

Module client 

Producer/Consumer client for the Hydra protocol, connects to the server, performs handshake, and sends/receives encrypted packets (AES-GCM).

Structs

Consumer
Unit structs to represent the Role::Consumer at the type level for better safety and clarity.
HydraClient
HydraClient - Cross-lang-friendly client connects to the HydraServer as a producer or consumer, performs handshake, and sends/receives encrypted packet (AES-GCM). It maintains an internal memory buffer (12 Mb) for zero-copy crypto and buffering.
Producer
Unit structs to represent the Role::Producer at the type level for better safety and clarity.