Producer/Consumer client for the Hydra protocol, connects to the server, performs handshake, and sends/receives encrypted packets (AES-GCM).
Structs
- Consumer
- Unit structs to represent the
Role::Consumerat the type level for better safety and clarity. - Hydra
Client - HydraClient -
Cross-lang-friendlyclient connects to theHydraServeras a producer or consumer, performs handshake, and sends/receives encrypted packet(AES-GCM). It maintains an internal memory buffer (12 Mb) for zero-copy crypto and buffering. - Producer
- Unit structs to represent the
Role::Producerat the type level for better safety and clarity.