pub fn decrypt_into(
input: &[u8],
output: &mut [u8],
key: &[u8; 32],
) -> Result<usize>Expand description
Decrypt input (which should be in the format produced by encrypt_into) into output using AES-256-GCM with the provided 32-byte key.
The output buffer must be input.len() - NONCE_LEN - TAG_LEN bytes,
returns the number of bytes written to output (the length of the decrypted plaintext) or an error if decryption fails.